# Welcome to Thunder!

You are using the Thunder CLI, your interface with the Thunder network. We encourage you to experiment with incorporating Thunder into your workflows, and believe the developer experience speaks for itself.

## Usage

Use thunder -h for detailed usage tips, but for 95% of use cases, you will use the simple "thunder {your code here}" command. Welcome to the future of cloud computing.

# requirements

click
requests
cryptography
common.utils
